aboutsummaryrefslogtreecommitdiff
path: root/generic/tkZinc.c
diff options
context:
space:
mode:
authorlecoanet2003-01-22 14:50:39 +0000
committerlecoanet2003-01-22 14:50:39 +0000
commit78740373985ac1d9ebbad3807a9ccc7b4db13def (patch)
treebcbd99cbe9e60b84d44fecd04ccc9beefbe182b0 /generic/tkZinc.c
parent53a7881c352125f7b66c81dbd6c5c2bb663c06e6 (diff)
downloadtkzinc-78740373985ac1d9ebbad3807a9ccc7b4db13def.zip
tkzinc-78740373985ac1d9ebbad3807a9ccc7b4db13def.tar.gz
tkzinc-78740373985ac1d9ebbad3807a9ccc7b4db13def.tar.bz2
tkzinc-78740373985ac1d9ebbad3807a9ccc7b4db13def.tar.xz
*** empty log message ***
Diffstat (limited to 'generic/tkZinc.c')
-rw-r--r--generic/tkZinc.c34
1 files changed, 11 insertions, 23 deletions
diff --git a/generic/tkZinc.c b/generic/tkZinc.c
index 696cb28..bdf14d2 100644
--- a/generic/tkZinc.c
+++ b/generic/tkZinc.c
@@ -1978,8 +1978,8 @@ ZnItemWithTagOrId(WidgetInfo *wi,
*
* Perform layouts on items. It can position items horizontally,
* vertically, along a path or with respect to a reference item.
* It can also align on a grid and resize items to a common
* reference.
*
*----------------------------------------------------------------------
*/
@@ -1991,16 +1991,14 @@ LayoutItems(WidgetInfo *wi,
int index, result;
Item item;
static CONST char *layout_cmd_strings[] = {
- "bbalign", "valign", "halign", "align",
- "position", "grid", "size", NULL
+ "align", "grid", "position", "scale", "space", NULL
};
enum layout_cmds {
- ZN_L_BBALIGN, ZN_L_VALIGN, ZN_L_HALIGN, ZN_L_ALIGN,
- ZN_L_POSITION, ZN_L_GRID, ZN_L_SIZE
+ ZN_L_ALIGN, ZN_L_GRID, ZN_L_POSITION, ZN_L_SCALE, ZN_L_SPACE
};
if (Tcl_GetIndexFromObj(wi->interp, args[0], layout_cmd_strings,
- "align command", 0, &index) != ZN_OK) {
+ "layout command", 0, &index) != ZN_OK) {
return ZN_ERROR;
}
switch((enum layout_cmds) index) {
@@ -2010,19 +2008,9 @@ LayoutItems(WidgetInfo *wi,
case ZN_L_ALIGN:
break;
/*
- * halign
- */
- case ZN_L_HALIGN:
- break;
- /*
- * valign
- */
- case ZN_L_VALIGN:
- break;
- /*
- * bbalign
+ * grid
*/
- case ZN_L_BBALIGN:
+ case ZN_L_GRID:
break;
/*
* position
@@ -2030,14 +2018,14 @@ LayoutItems(WidgetInfo *wi,
case ZN_L_POSITION:
break;
/*
- * grid
+ * scale
*/
- case ZN_L_GRID:
+ case ZN_L_SCALE:
break;
/*
- * size
+ * space
*/
- case ZN_L_SIZE:
+ case ZN_L_SPACE:
break;
}
@@ -1978,8 +1978,8 @@ ZnItemWithTagOrId(WidgetInfo *wi,
* Perform layouts on items. It can position items horizontally,
* vertically, along a path or with respect to a reference item.
- * It can also align on a grid and resize items to a common
- * reference.
+ * It can also align on a grid, evenly space items and resize
+ * items to a common reference.
*
*----------------------------------------------------------------------